diff qtrle.c @ 4494:ce643a22f049 libavcodec

Replace deprecated PIX_FMT names by the newer variants.
author diego
date Wed, 07 Feb 2007 01:48:09 +0000
parents 05e932ddaaa9
children 66ef3690d108
line wrap: on
line diff
--- a/qtrle.c	Tue Feb 06 23:58:02 2007 +0000
+++ b/qtrle.c	Wed Feb 07 01:48:09 2007 +0000
@@ -29,7 +29,7 @@
  * The QT RLE decoder has seven modes of operation:
  * 1, 2, 4, 8, 16, 24, and 32 bits per pixel. For modes 1, 2, 4, and 8
  * the decoder outputs PAL8 colorspace data. 16-bit data yields RGB555
  * data. 24-bit data is RGB24 and 32-bit data is RGBA32.
  */
 
 #include <stdio.h>
@@ -515,7 +515,7 @@
         break;
 
     case 32:
-        avctx->pix_fmt = PIX_FMT_RGBA32;
+        avctx->pix_fmt = PIX_FMT_RGB32;
         break;
 
     default:
@@ -29,7 +29,7 @@
  * 1, 2, 4, 8, 16, 24, and 32 bits per pixel. For modes 1, 2, 4, and 8
  * the decoder outputs PAL8 colorspace data. 16-bit data yields RGB555
- * data. 24-bit data is RGB24 and 32-bit data is RGBA32.
+ * data. 24-bit data is RGB24 and 32-bit data is RGB32.
  */
 